<template>
  <view class="inspection-app">
    <!-- 刷新页面后的顶部提示框 -->
    <view class="tips" :class="{ 'tips-ani': tipShow }">刷新成功</view>

    <!-- 顶部筛选区 -->
    <view class="filter-section">
      <view class="filter-controls">
        <!-- 查询条件选择器 -->
        <view class="dropdown-filter">
          <picker @change="onOptionsChange" :value="optionsIndex" :range="options">
            <view class="picker">{{options[optionsIndex]}}</view>
          </picker>
        </view>
        
        <!-- 搜索框 -->
        <view class="search-container">
          <input class="search-input" v-model="searchValue" :placeholder="'请输入'+options[optionsIndex]" @confirm="btnclicked" />
          <button class="search-button" @click="btnclicked">搜索</button>
        </view>
        
        <!-- 状态切换标签 -->
        <view class="status-tabs">
          <button :class="['tab-button', current === 0 ? 'active' : '']" @click="onClickItem({currentIndex: 0})">
            {{items[0]}}
          </button>
          <button :class="['tab-button', current === 1 ? 'active' : '']" @click="onClickItem({currentIndex: 1})">
            {{items[1]}}
          </button>
        </view>
      </view>
    </view>

    <!-- 检验单列表 -->
    <view class="inspection-list">
      <!-- 检验单卡片 -->
      <view class="inspection-card" v-for="item in data" :key="item.id" @click="navigateToDetail(item)">
        <view class="card-header">
          <text class="badge normal" v-if="item.SJ_MJ">{{item.SJ_MJ}}</text>
          <text class="card-title">检验单号: {{item.billNo}}</text>
          <text class="status pass" v-if="item.result === '合格'">合格</text>
          <text class="status unqualified" v-if="item.result === '不合格'">不合格</text>
          <text class="status pending" v-if="!item.result">待检验</text>
        </view>

        <view class="card-body">
          <view class="info-row">
            <view class="info-item">
              <text class="info-label">物料信息</text>
              <text class="info-content">{{item.itemNo}}<br>{{item.daa003}}</text>
            </view>
            <view class="info-item">
              <text class="info-label">规格型号</text>
              <text class="info-content">{{item.daa004}}</text>
            </view>
          </view>

          <view class="info-row">
            <view class="info-item">
              <text class="info-label">产线</text>
              <text class="info-content">{{item.line}}</text>
            </view>
            <view class="info-item">
              <text class="info-label">工单数量</text>
              <text class="info-content highlight">{{item.daa008}}</text>
            </view>
          </view>

          <view class="info-row">
            <view class="info-item">
              <text class="info-label">销售订单</text>
              <text class="info-content">{{item.caa015}}</text>
            </view>
            <view class="info-item">
              <text class="info-label">客户</text>
              <text class="info-content">{{item.cust}}</text>
            </view>
          </view>

          <view class="meta-info">
            <text class="meta-item">
              <uni-icons type="calendar" size="14" color="#95a5a6"></uni-icons>
              {{item.statusDate}}
            </text>
            <text class="meta-item">
              <uni-icons type="person" size="14" color="#95a5a6"></uni-icons>
              创建人: {{item.fName}}
            </text>
          </view>
          
          <view class="meta-info" v-if="item.statusUser">
            <text class="meta-item">
              <uni-icons type="person" size="14" color="#95a5a6"></uni-icons>
              检验人: {{item.statusUser}}
            </text>
          </view>
        </view>

        <view class="card-actions">
          <button class="primary" @click.stop="navigateToDetail(item)">
            {{current === 0 ? '开始检验' : '查看详情'}}
          </button>
        </view>
      </view>
    </view>

    <!-- 新增按钮 -->
    <view class="plus-button" @click="handleFabClick">
      +
    </view>
  </view>
</template>

<script>
export default {
  components: {},
  data() {
    return {
      items: ['未完成', '已完成'],
      current: 0,
      data: [],
      tipShow: false ,// 是否显示顶部提示框
	  searchValue: '',
      // ===== 新增搜索功能相关数据 =====
      optionsIndex: 0, // 当前选择的查询条件索引
      options: ['工单', '检验单号', '产线', '物料编码', '物料名称'], // 查询条件选项
      selectedField: 'daa001' // 当前选择的查询字段，默认为工单
    };
  },
  onLoad() {
    //页面加载时调用的事件
    this.init();
  },
  methods: {
    // ===== 新增查询条件选择方法 =====
    onOptionsChange(e) {
      this.optionsIndex = e.detail.value;
      // 根据选择的选项设置搜索字段
      const fieldMap = {
        0: 'daa001',     // 工单
        1: 'billNo',     // 检验单号
        2: 'line',       // 产线
        3: 'itemNo',     // 物料编码
        4: 'daa003'      // 物料名称(产品名称)
      };
      this.selectedField = fieldMap[this.optionsIndex];
    },
    
    //搜索框点击事件
    btnclicked() {
      this.init();
    },
    
    init() {
      //获取搜索条件内容
      let SearchValue = this.searchValue;
      
      let result = "未完成";
      if (this.current === 1) {
        result = "已完成";
      }
      
      // ===== 修改后的API调用，添加搜索字段参数 =====
      //页面加载时调用的事件
      this.$post({
        url: "/SJ/GetPage",
        data: {
          pageIndex: 1,
          limit: 20,
          statusUser: this.$loginInfo.account,
          result: result,
          SearchValue: SearchValue,
          selectedIndex: this.optionsIndex, // 新增：搜索条件索引
          searchField: this.selectedField   // 新增：搜索字段名
        }
      }).then(res => {
        this.data = res.data.tbBillList;
      })
    },
    handleFabClick() {
      uni.navigateTo({
        url: 'Add?id'
      });
    },
    onClickItem(index) {
      if (this.current !== index.currentIndex) {
        this.current = index.currentIndex;
        this.init();
      }
    },
    navigateToDetail(item) {
      uni.navigateTo({
        url: 'Add?id=' + item.id + '&billNo=' + item.billNo
      });
    },
  },
  /**
   * 下拉刷新回调函数
   */
  onPullDownRefresh() {
    //重新执行一遍查询
    this.init();
    this.tipShow = true;
    //关闭动画
    uni.stopPullDownRefresh();

    setTimeout(function () {
      this.tipShow = false;
    }, 3000);
  },
  /**
   * 上拉加载回调函数
   */
  onReachBottom() {
    this.init();
  },
  onShow() {
    //每次进入页面都会执行的方法
    this.init();
  }
};
</script>

<style scoped>
/* 基础样式重置 */
.inspection-app {
  padding: 10px;
  background-color: #f5f7fa;
  min-height: 100vh;
}

/* 顶部筛选区 */
.filter-section {
  margin-bottom: 24px;
}

.filter-controls {
  display: flex;
  flex-wrap: wrap;
  gap: 10px;
}

/* 查询条件选择器 */
.dropdown-filter {
  min-width: 80px;
  margin-right: 10px;
}

.picker {
  padding: 8px 12px;
  border: 1px solid #ddd;
  border-radius: 4px;
  background-color: white;
  font-size: 14px;
  min-width: 80px;
}

/* 搜索框样式 */
.search-container {
  display: flex;
  flex: 1;
  margin-right: 10px;
  height: 36px;
  min-width: 200px;
}

.search-input {
  flex: 1;
  padding: 8px 12px;
  border: 1px solid #ddd;
  border-radius: 4px 0 0 4px;
  font-size: 14px;
  background-color: white;
}

.search-button {
  padding: 0 12px;
  border: 1px solid #3498db;
  border-radius: 0 4px 4px 0;
  background-color: #3498db;
  color: white;
  font-size: 14px;
  margin: 0;
}

.status-tabs {
  display: flex;
  border-radius: 4px;
  overflow: hidden;
  background-color: #ecf0f1;
  flex: 1;
  min-width: 200px;
}

.tab-button {
  padding: 0px 16px;
  border: none;
  background: none;
  font-size: 14px;
  transition: all 0.3s;
  margin: 0;
  height: 35px;
  flex: 1;
}

.tab-button.active {
  background-color: #3498db;
  color: white;
}

/* 检验单列表 */
.inspection-list {
  display: flex;
  flex-direction: column;
  gap: 20px;
}

/* 检验单卡片 */
.inspection-card {
  background-color: white;
  border-radius: 8px;
  box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
  overflow: hidden;
  transition: all 0.3s;
}

.card-header {
  padding: 16px;
  border-bottom: 1px solid #eee;
  display: flex;
  align-items: center;
}

.card-title {
  font-size: 16px;
  font-weight: 600;
  flex: 1;
  margin: 0 8px;
}

.badge {
  font-size: 12px;
  padding: 2px 6px;
  border-radius: 10px;
  margin-right: 8px;
}

.badge.normal {
  background-color: #3498db;
  color: white;
}

.status {
  font-size: 12px;
  padding: 4px 8px;
  border-radius: 4px;
  font-weight: 500;
}

.status.pending {
  background-color: #f39c12;
  color: white;
}

.status.pass {
  background-color: #00cd00;
  color: white;
}

.status.unqualified {
  background-color: #ff0000;
  color: white;
}

.card-body {
  padding: 16px;
}

.info-row {
  display: flex;
  margin-bottom: 12px;
  gap: 16px;
}

.info-item {
  flex: 1;
}

.info-label {
  display: block;
  font-size: 12px;
  color: #7f8c8d;
  margin-bottom: 4px;
}

.info-content {
  font-size: 14px;
  color: #2c3e50;
  line-height: 1.5;
}

.highlight {
  font-weight: 600;
  color: #2c3e50;
  font-size: 16px;
}

.meta-info {
  display: flex;
  gap: 16px;
  font-size: 12px;
  color: #95a5a6;
  margin-top: 12px;
}

.meta-item {
  display: flex;
  align-items: center;
  gap: 4px;
}

.card-actions {
  padding: 12px 16px;
  border-top: 1px solid #eee;
  display: flex;
  gap: 8px;
}

button {
  padding: 8px 16px;
  border: 1px solid #ddd;
  border-radius: 4px;
  background-color: white;
  font-size: 14px;
  transition: all 0.2s;
  flex: 1;
}

button.primary {
  background-color: #3498db;
  color: white;
  border-color: #2980b9;
}

.plus-button {
  position: fixed;
  bottom: 20px;
  right: 20px;
  width: 60px;
  height: 60px;
  border-radius: 50%;
  background-color: #3498db;
  color: #ffffff;
  text-align: center;
  line-height: 59px;
  font-size: 24px;
  cursor: pointer;
  z-index: 1000;
  margin-bottom: 35px;
}

.tips {
  color: #67c23a;
  font-size: 14px;
  line-height: 40px;
  text-align: center;
  background-color: #f0f9eb;
  height: 0;
  opacity: 0;
  transform: translateY(-100%);
  transition: all 0.3s;
}

.tips-ani {
  transform: translateY(0);
  height: 40px;
  opacity: 1;
}

/* 响应式设计 */
@media (min-width: 768px) {
  .inspection-list {
    display: grid;
    grid-template-columns: repeat(auto-fill, minmax(400px, 1fr));
  }
  
  .info-row {
    flex-direction: row;
  }
}

@media (min-width: 300px) {
  .inspection-list {
    display: grid;
    grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
  }
  
  .info-row {
    flex-direction: row;
  }
}
</style>